@@ -1,22 +1,16 @@
 use crate::LoggerError;
+use serde::Deserialize;
 use std::str::FromStr;
-use clap::Parser;
 
 /// Defines the Logger configuration.
-#[derive(Debug, Clone, Parser)]
-#[clap(rename_all = "kebab-case")]
-#[clap(setting = clap::AppSettings::AllowExternalSubcommands)]
+#[derive(Debug, Clone, Deserialize)]
+#[serde(default)]
 pub struct LoggerConfig {
     /// Sets the logger [`EnvFilter`].
     /// Valid values: trace, debug, info, warn, error
     /// Example of a valid filter: "warn,my_crate=info,my_crate::my_mod=debug,[my_span]=trace"
-    #[clap(long, env = "LS_LOGGER_LEVEL", default_value = "debug")]
     pub env_filter: String,
-
-    #[clap(flatten)]
     pub stdout_output: StandardOutputConfig,
-
-    #[clap(flatten)]
     pub file_output: FileOutputConfig,
 }
 
@@ -30,15 +24,12 @@ impl Default for LoggerConfig {
     }
 }
 
-#[derive(Debug, Clone, Parser)]
-#[clap(rename_all = "kebab-case")]
+#[derive(Debug, Clone, Deserialize)]
+#[serde(default)]
 pub struct StandardOutputConfig {
     /// Determines whether the Logger should print to standard output.
     /// Valid values: true, false
-    #[clap(long, env = "LS_LOGGER_STDOUT_OUTPUT_ENABLED", parse(try_from_str), default_value = "true")]
     pub stdout_enabled: bool,
-
-    #[clap(long, env = "LS_LOGGER_STDOUT_OUTPUT_USE_ANSI_COLORS", parse(try_from_str), default_value = "true")]
     pub stdout_use_ansi_colors: bool,
 }
 
@@ -48,24 +39,20 @@ impl Default for StandardOutputConfig {
     }
 }
 
-#[derive(Debug, Clone, Parser)]
-#[clap(rename_all = "kebab-case")]
+#[derive(Debug, Clone, Deserialize)]
+#[serde(default)]
 pub struct FileOutputConfig {
     /// Determines whether the Logger should print to a file.
     /// Valid values: true, false
-    #[clap(long, env = "LS_LOGGER_FILE_OUTPUT_ENABLED", parse(try_from_str), default_value = "false")]
     pub file_output_enabled: bool,
 
     /// The log file location
-    #[clap(long, env = "LS_LOGGER_FILE_OUTPUT_DIR", default_value = "/tmp")]
     pub file_output_directory: String,
 
     /// The log file name's _prefix_
-    #[clap(long, env = "LS_LOGGER_FILE_OUTPUT_NAME_PREFIX", default_value = "output.log")]
     pub file_output_name_prefix: String,
 
     /// The log file rotation strategy
-    #[clap(long, env = "LS_LOGGER_FILE_OUTPUT_ROTATION", default_value = "daily")]
     pub file_output_rotation: Rotation,
 }
 
@@ -73,14 +60,14 @@ impl Default for FileOutputConfig {
     fn default() -> Self {
         Self {
             file_output_enabled: false,
-            file_output_directory: "".to_owned(),
-            file_output_name_prefix: "".to_owned(),
-            file_output_rotation: Rotation::Daily,
+            file_output_directory: ".".to_owned(),
+            file_output_name_prefix: "output.log".to_owned(),
+            file_output_rotation: Rotation::Never,
         }
     }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
+#[derive(Clone, Debug, PartialEq, Eq, Hash, Deserialize)]
 pub enum Rotation {
     Minutely,
     Hourly,
@@ -113,12 +100,6 @@ impl Rotation {
     }
 }
 
-impl LoggerConfig {
-    pub fn build() -> Self {
-        Self::parse()
-    }
-}
-
 #[cfg(test)]
 mod test {
 
@@ -126,7 +107,7 @@ mod test {
 
     #[test]
     fn should_build_config() {
-        let config = LoggerConfig::build();
+        let config: LoggerConfig = config::Config::builder().build().unwrap().try_deserialize().unwrap();
         assert!(config.stdout_output.stdout_enabled);
     }
 }
